DividedMatrix

Struct DividedMatrix 

pub(crate) struct DividedMatrix<const LIMBS: usize, MATRIX: Unit> {
    pub(super) inner: MATRIX,
    pub k: u32,
    pub k_upper_bound: u32,
}
A matrix whose elements still need to be divided by 2^k.

Since some of the operations conditionally increase k, this struct furthermore keeps track of k_upper_bound; an upper bound on the value of k.

Fields

inner: MATRIXk: u32k_upper_bound: u32

Implementations

Source

impl<const LIMBS: usize> DividedMatrix<LIMBS, IntMatrix<LIMBS>>

pub(super) const fn conditional_negate_top_row(&mut self, negate: Choice)

Negate the top row of this matrix if negate; otherwise do nothing.

pub(super) const fn conditional_negate_bottom_row(&mut self, negate: Choice)

Negate the bottom row of this matrix if negate; otherwise do nothing.

pub(super) const fn to_divided_pattern_matrix( self, ) -> DividedPatternMatrix<LIMBS>