pub(crate) struct IntMatrix<const LIMBS: usize> {
m00: ExtendedInt<LIMBS, 1>,
m01: ExtendedInt<LIMBS, 1>,
m10: ExtendedInt<LIMBS, 1>,
m11: ExtendedInt<LIMBS, 1>,
}Expand description
2x2-Matrix with integers for elements.
Representation
The internal state represents the matrix
[ m00 m01 ]
[ m10 m11 ]Fields
m00: ExtendedInt<LIMBS, 1>m01: ExtendedInt<LIMBS, 1>m10: ExtendedInt<LIMBS, 1>m11: ExtendedInt<LIMBS, 1>Implementations
Sourceimpl<const LIMBS: usize> IntMatrix<LIMBS>
impl<const LIMBS: usize> IntMatrix<LIMBS>
Sourcepub(super) const fn conditional_negate_top_row(&mut self, negate: Choice)
pub(super) const fn conditional_negate_top_row(&mut self, negate: Choice)
Negate the top row of this matrix if negate; otherwise do nothing.
Sourcepub(super) const fn conditional_negate_bottom_row(&mut self, negate: Choice)
pub(super) const fn conditional_negate_bottom_row(&mut self, negate: Choice)
Negate the bottom row of this matrix if negate; otherwise do nothing.
pub(super) const fn to_pattern_matrix(self) -> PatternMatrix<LIMBS>